from typing import Mapping

from wexample_helpers.const.types import StringsList

BasicInlineValue = str | int | float | bool | None
CoreCommandArgsDict = Mapping[str, BasicInlineValue]
CoreCommandArgsList = StringsList



from wexample_wex_addon_app.utils.AppDirectoryStructure import AppDirectoryStructure


class KernelDirectoryStructure(AppDirectoryStructure):
    should_exist: bool = True


KernelDirectoryStructure.model_rebuild()



from wexample_filestate.const.enums import DiskItemType
from wexample_filestate.const.types import StateItemConfig
from wexample_filestate.file_state_manager import FileStateManager
from wexample_helpers.const.types import *
from wexample_wex_core.const.globals import WORKDIR_SETUP_DIR


class Workdir(FileStateManager):

    def build_config(self, config: Optional[StateItemConfig] = None) -> StateItemConfig:
        config = super().build_config(config)

        if "children" not in config:
            config["children"] = []

        config["children"].append(self.build_setup_config())

        return config or {}

    def build_setup_config(self, config: Optional[StateItemConfig] = None) -> StateItemConfig:
        return {
            "children": [],
            "name": WORKDIR_SETUP_DIR,
            "type": DiskItemType.DIRECTORY,
            "should_exist": True
        }


Workdir.model_rebuild()



import os
import sys
from typing import Dict, Optional

from wexample_helpers_app.utils.abstract_kernel import AbstractKernel
from wexample_wex_core.core.file.KernelDirectoryStructure import KernelDirectoryStructure


class Kernel(AbstractKernel):
    directory: Optional[KernelDirectoryStructure]

    def __init__(self, entrypoint_path: str) -> None:
        super().__init__()
        self._sys_argv: list[str] = sys.argv.copy()

        root_path = os.path.dirname(os.path.realpath(entrypoint_path)) + os.sep

        self._path: Dict[str, str] = {
            "root": root_path,
        }

        self.directory = KernelDirectoryStructure.create_from_path(
            path=root_path,
        )

    def call(self) -> None:
        """
        Main entrypoint from bash call.
        May never be called by an internal script.
        :return:
        """

        # No arg found except process id
        if not len(self._sys_argv) > 2:
            return
